@@ -19,6 +19,17 @@ class Car(rabbyt.Sprite):
         self.shadow = rabbyt.Sprite(name+"shadow.png", self.shape)
         self.shadow.alpha = .5
 
+        # These three lines make use of a rather experimental feature of rabbyt.
+        # At the end of update() I have left commented out a more traditional
+        # method of doing the same thing.
+        self.shadow.rot = lambda: self.rot
+        self.shadow.x = lambda: self.x - 4
+        self.shadow.y = lambda: self.y - 5
+        # Here is another method with identical results (only faster):
+        #self.shadow.rot = self.attrgetter('rot')
+        #self.shadow.x = self.attrgetter('x') - 4
+        #self.shadow.y = self.attrgetter('y') - 5
+
         self.dust_r = (-15, 10)
         self.dust_l = (-15,-10)
 
@@ -71,9 +82,9 @@ class Car(rabbyt.Sprite):
         self.x += self.velocity[0]
         self.y += self.velocity[1]
 
-        self.shadow.x = self.x - 4
-        self.shadow.y = self.y - 5
-        self.shadow.rot = self.rot
+        #self.shadow.x = self.x - 4
+        #self.shadow.y = self.y - 5
+        #self.shadow.rot = self.rot
 
 
     def create_boost_particle(self):
