@@ -22,12 +22,14 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 """)
 
 __author__ = "Matthew Marshall <matthew@matthewmarshall.org>"
-__version__ = "0.0.2"
+__version__ = "0.0.3"
 
 import heapq
 import os.path
 
 from rabbyt._rabbyt import *
+from rabbyt.sprites import *
+from rabbyt.dynamicvalues import *
 
 extend_types = dict(constant=1, extrapolate=2, repeat=3, reverse=4)
 
@@ -73,18 +75,18 @@ def lerp(start, end, startt=None, endt=None, dt=None, extend="constant"):
     try:
         iter(start), iter(end)
     except TypeError:
-        return AnimLerp(start, end, startt, endt, extend)
+        return DVLerp(start, end, startt, endt, extend)
     else:
-        return [AnimLerp(s, e, startt, endt, extend)
+        return [DVLerp(s, e, startt, endt, extend)
                 for s,e in zip(start, end)]
 
 def wrap(bounds, parent, static=True):
     try:
         iter(parent)
     except TypeError:
-        return AnimWrap(bounds, parent, static)
+        return DVWrap(bounds, parent, static)
     else:
-        return tuple([AnimWrap(bounds, p, static) for p in parent])
+        return tuple([DVWrap(bounds, p, static) for p in parent])
 
 def bezier3(p0, p1, p2, p3, startt=None, endt=None, dt=None, extend="constant"):
     extend = extend_types[extend]
@@ -93,9 +95,9 @@ def bezier3(p0, p1, p2, p3, startt=None, endt=None, dt=None, extend="constant"):
     try:
         [iter(p) for p in [p0,p1,p2,p3]]
     except TypeError:
-        return AnimStaticCubicBezier(p0, p1, p2, p3, startt, endt, extend)
+        return DVStaticCubicBezier(p0, p1, p2, p3, startt, endt, extend)
     else:
-        return [AnimStaticCubicBezier(p0, p1, p2, p3, startt, endt, extend)
+        return [DVStaticCubicBezier(p0, p1, p2, p3, startt, endt, extend)
                 for p0, p1, p2, p3 in zip(p0, p1, p2, p3)]
 
 
